# Generated by roxygen2: do not edit by hand

export(bam2DNAStringSet)
export(bam2DNAStringSet2)
export(bs_aln)
export(bs_consensus)
export(bs_filter)
export(bs_hamming)
export(bs_rename)
export(clw_read)
export(consensus)
export(download_genbank)
export(fa_combine)
export(fa_filter)
export(fa_read)
export(fa_rename)
export(fa_to_interleaved)
export(fa_to_sequential)
export(fa_write)
export(fas2phy)
export(gb_read)
export(get_id)
export(mega_read)
export(ncbi_fa_read)
export(phy2fas)
export(phy_read)
export(phy_write)
export(renameTXT)
export(replaceInside)
export(seqlen)
export(sth_read)
importFrom(Biostrings,AAStringSet)
importFrom(Biostrings,BStringSet)
importFrom(Biostrings,DNAStringSet)
importFrom(Biostrings,RNAStringSet)
importFrom(Biostrings,consensusMatrix)
importFrom(Biostrings,matchPattern)
importFrom(Biostrings,readAAStringSet)
importFrom(Biostrings,readBStringSet)
importFrom(Biostrings,readDNAStringSet)
importFrom(Biostrings,readRNAStringSet)
importFrom(Biostrings,toString)
importFrom(Biostrings,width)
importFrom(Biostrings,writeXStringSet)
importFrom(magrittr,"%<>%")
importFrom(magrittr,"%>%")
importFrom(stats,setNames)
importFrom(utils,download.file)
importFrom(utils,read.delim)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(yulab.utils,use_perl)
