# Personal spelling dictionary for `R CMD check --as-cran`.
# Keeps the default 'en_stats' dictionary and adds package-specific
# technical terms so that the DESCRIPTION spell check does not flag
# them as "possibly misspelled words".
#
# The word list used to build seqmagick.rds is:
#   GC, gzip, bzip, xz, FASTA, PHYLIP, CLUSTAL, STOCKHOLM, MEGA,
#   GenBank, NCBI, Biostrings, seqmagick
description <- list(
    dictionaries = c("en_stats", "seqmagick")
)
