% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bam2DNAStringSet.R
\name{bam2DNAStringSet2}
\alias{bam2DNAStringSet2}
\title{bam2DNAStringSet2}
\usage{
bam2DNAStringSet2(bamfile, refseq)
}
\arguments{
\item{bamfile}{bam file}

\item{refseq}{refseq, DNAStringSet object}
}
\value{
list of DNAStringSet objects
}
\description{
convert bam file to aligned fasta file
}
\author{
Guangchuang Yu
}
