% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/seqlen.R
\name{seqlen}
\alias{seqlen}
\title{seqlen}
\usage{
seqlen(fasfile)
}
\arguments{
\item{fasfile}{fasta file}
}
\value{
numeric vector
}
\description{
sequence length
}
\author{
Guangchuang Yu
}
