% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/seqlen.R
\name{fa_summary}
\alias{fa_summary}
\title{fa_summary}
\usage{
fa_summary(x)
}
\arguments{
\item{x}{fasta file or XStringSet object}
}
\value{
data.frame with one row: \code{n_seq}, \code{min_len},
\code{max_len}, \code{mean_len}, \code{GC_pct} and \code{ambiguous_pct}
}
\description{
summarize sequences in a fasta file
}
\details{
Compute number of sequences, length distribution, GC content and
proportion of ambiguous characters (anything other than A/C/G/T/U,
including gaps).
}
\examples{
fa_file <- system.file("extdata/HA.fas", package="seqmagick")
fa_summary(fa_file)
}
\author{
Guangchuang Yu
}
